pub struct ExcelExporter { /* private fields */ }Expand description
Excel exporter for v1.0.0 array models and v5.0.0 scalar models
Implementations
Sourceimpl ExcelExporter
impl ExcelExporter
Sourcepub fn new(model: ParsedModel) -> Self
pub fn new(model: ParsedModel) -> Self
Create a new Excel exporter
Sourcepub fn export(&self, output_path: &Path) -> ForgeResult<()>
pub fn export(&self, output_path: &Path) -> ForgeResult<()>
Export the model to an Excel .xlsx file
Errors
Returns an error if the workbook cannot be saved to the specified path.
Sourcepub fn export_to_buffer(&self) -> ForgeResult<Vec<u8>>
pub fn export_to_buffer(&self) -> ForgeResult<Vec<u8>>
Export the model to an in-memory Excel buffer.
Errors
Returns an error if the workbook cannot be serialized.