pub fn parse_nested_scalars(
parent_key: &str,
map: &Mapping,
model: &mut ParsedModel,
) -> ForgeResult<()>Expand description
Parse nested scalar variables (e.g., summary.total, summary.average)
Errors
Returns an error if a nested scalar name is not a string or has an invalid format.