parse_table

Function parse_table 

pub fn parse_table(name: &str, map: &Mapping) -> ForgeResult<Table>
Parse a table from a YAML mapping (v4.0 enhanced with metadata)

Errors

Returns an error if a column name is not a string, or column data has an invalid type or format.